==> code-browser-1.3-src.tar.gz: code-browser-1.3/samples/tutorial.c <==
//[c]This is a quick introduction to Code Browser.
//[c]
//[c]Code Browser supports 4 types of lines:
	This is a text line
//[c]	This is a comment line
//[of]:	This is a folder line (blue)
//[c]This is a sample folder
//[c]
int dummy = 123
const char * strDummy = "abc";
//[cf]
//[l]:	This is a link line (green):files/string.cpp
//[c]
//[c]* A text line is a basic lines, it appears as is in the source file.
//[c]* A comment line is a special comment line: 
//[c]	the comment prefix is not displayed, but the line has a different
//[c]	background and a different font (it can be customized).
//[c]* A folder line is a line that embed other lines
//[c]	Such lines can be 'entered': the context changes and shows
//[c]	the content of the folder.
//[c]* A link line is a reference to another file or another sub-folder.
//[c]	Links can be 'entered' in the same way as folders.
//[c]	The specified file is opened in the same window.
//[c]
//[c]Usual actions on folder and link lines
//[c]
//[c]	Entering a folder or a link
//[c]		- With mouse: double click on the line
//[c]		- With keyboard: ALT-RIGHT
//[c]		- In menu: Go/Enter
//[c]		
//[c]	Leaving the current folder
//[c]		- With keyboard: ALT-LEFT
//[c]		- In menu: Go/Back
//[c]	
//[c]	Editing link or folder properties
//[c]		When caret on a link line or a folder lines:
//[c]		- With keyboard: ALT-ENTER
//[c]		- In menu: Edit/Properties
//[c]	
//[c]	Other useful shortcuts:
//[c]		- ALT-DOWN: move caret to next folder or link
//[c]		- ALT-UP: move caret to previous folder or link
//[c]		- CTRL-SHIFT-F: create a new folder
//[c]		- CTRL-SHIFT-L: create a new link
//[c]		- CTRL-SHIFT-C: create a new comment line
//[c]		- CTRL-SHIFT-T: create a new text line
//[c]		- CTRL-SHIFT-DOWN: go to the next 'sibling' folder or link
//[c]		- CTRL-SHIFT-UP: go to the previous 'sibling' folder or link
//[c]
//[c]Example 1 - Basics
//[c]
//[c]	The following files are in C++ and attempt to show how folding can 
//[c]	help to navigate and view source code.
//[c]	
//[l]:	string.cpp:files/string.cpp
//[l]:	dictionary.cpp:files/dictionary.cpp
//[c]
//[c]	Note that folding is not limited to programming languages.	It can be 
//[c]	useful for any structured text files such as HTML, XML or TeX.
//[c]
//[c]Example 2 - Smalltalk-like browsing
//[c]
//[c]	The following example is a variant of the previous 'string.cpp' example.
//[c]	It add one level of folding and takes advantage of the smalltalk-like
//[c]	browsing mode:
//[c]
//[l]:	string2.cpp:files/string2.cpp
//[c]
//[c]Example 3 - XML Docbook
//[c]
//[c]	This is the docbook source of the code browser documentation.
//[c]	Open the file in a new tab (CTRL-T) and use 'Two vertical panes' or 
//[c]	'Vertical Browser - Three Panes' to navigate into the document. This 
//[c]	example shows how the program can be used to outline an XML 
//[c]	document.
//[c]
//[l]:	code-browser.xml:files/code-browser.xml
//[c]
//[c]More Examples
//[c]
//[c]	As an example of a larger project using folding, you can have a look
//[c]	at the source of the editor: open 'project.zc' at the root of the 
//[c]	distribution (the library files are not fully structured yet).

==> code-browser-2.4-src.tar.gz: code-browser-2.4/samples/tutorial.c <==
//[c]This is a quick introduction to Code Browser.
//[c]
//[c]Code Browser supports 4 types of lines:
	This is a text line
//[c]	This is a comment line
//[of]:	This is a folder line (blue)
//[c]This is a sample folder
//[c]
int dummy = 123
const char * strDummy = "abc";
//[cf]
//[l]:	This is a link line (green):files/string.cpp
//[c]
//[c]* A text line is a basic lines, it appears as is in the source file.
//[c]* A comment line is a special comment line: 
//[c]	the comment prefix is not displayed, but the line has a different
//[c]	background and a different font (it can be customized).
//[c]* A folder line is a line that embed other lines
//[c]	Such lines can be 'entered': the context changes and shows
//[c]	the content of the folder.
//[c]* A link line is a reference to another file or another sub-folder.
//[c]	Links can be 'entered' in the same way as folders.
//[c]	The specified file is opened in the same window.
//[c]
//[c]Usual actions on folder and link lines
//[c]
//[c]	Entering a folder or a link
//[c]		- With mouse: double click on the line
//[c]		- With keyboard: ALT-RIGHT
//[c]		- In menu: Go/Enter
//[c]		
//[c]	Leaving the current folder
//[c]		- With keyboard: ALT-LEFT
//[c]		- In menu: Go/Back
//[c]	
//[c]	Editing link or folder properties
//[c]		When caret on a link line or a folder lines:
//[c]		- With keyboard: ALT-ENTER
//[c]		- In menu: Edit/Properties
//[c]	
//[c]	Other useful shortcuts:
//[c]		- ALT-DOWN: move caret to next folder or link
//[c]		- ALT-UP: move caret to previous folder or link
//[c]		- CTRL-SHIFT-F: create a new folder
//[c]		- CTRL-SHIFT-L: create a new link
//[c]		- CTRL-SHIFT-C: create a new comment line
//[c]		- CTRL-SHIFT-T: create a new text line
//[c]		- CTRL-SHIFT-DOWN: go to the next 'sibling' folder or link
//[c]		- CTRL-SHIFT-UP: go to the previous 'sibling' folder or link
//[c]
//[c]Example 1 - Basics
//[c]
//[c]	The following files are in C++ and attempt to show how folding can 
//[c]	help to navigate and view source code.
//[c]	
//[l]:	string.cpp:files/string.cpp
//[l]:	dictionary.cpp:files/dictionary.cpp
//[c]
//[c]	Note that folding is not limited to programming languages.	It can be 
//[c]	useful for any structured text files such as HTML, XML or TeX.
//[c]
//[c]Example 2 - Smalltalk-like browsing
//[c]
//[c]	The following example is a variant of the previous 'string.cpp' example.
//[c]	It add one level of folding and takes advantage of the smalltalk-like
//[c]	browsing mode:
//[c]
//[l]:	string2.cpp:files/string2.cpp
//[c]
//[c]Example 3 - XML Docbook
//[c]
//[c]	This is the docbook source of the code browser documentation.
//[c]	Open the file in a new tab (CTRL-T) and use the 'Tree View' 
//[c]	layout (it should be activated by default) to navigate into the document. 
//[c]	This example shows how the program can be used to outline an XML 
//[c]	document.
//[c]
//[l]:	code-browser.xml:files/code-browser.xml
//[c]
//[c]More Examples
//[c]
//[c]	As an example of a larger project using folding, you can have a look
//[c]	at the source of the editor: open 'project.zc' at the root of the 
//[c]	distribution (the library files are not fully structured yet).
